@@ -1,7 +1,7 @@
 import os
 import json
 import copy
-from datetime import datetime, timedelta
+from datetime import datetime
 
 
 def get_config():
@@ -48,6 +48,39 @@ def if_empty(object):
             return True
     return False
 
+
+def object_mapper(object, result):
+    mapped_object = {}
+    x = 0
+    for key in object:
+        if key not in ["created_at", "updated_at"]:
+            mapped_object[key] = result[x]
+            x += 1
+
+    return mapped_object
+
+def is_json(object):
+    try:
+        json_object = json.loads(object)
+        for x, y in json_object.items():
+            pass
+    except:
+        return False
+    return True
+
+
+def is_list_of_jsons(payload):
+
+    try:
+        for item in payload:
+            if is_json(json.dumps(item)) is True:
+                continue
+            else:
+                return False
+        return True
+    except:
+        return False
+
 def make_instert_string(object, table):
 
     fileds = ""
@@ -89,53 +122,40 @@ def make_instert_string(object, table):
     return insert_string
 
 
-def if_request_valid(config, payload, db_object):
-    print("CHECKING REQUEST VALIDITY >>>")
+def make_update_string(object, table, key, key_value):
 
+    string = ""
 
-    required_items = copy.deepcopy(db_object)
-    #print(required_items)
-    required_items.pop("created_at")
-    required_items.pop("updated_at")
-    #required_items.pop("news_id")
+    for name, value in object.items():
+        if name != key:
+            if type(value) == str:
+                value = value.replace("'", "''")
 
+            if type(value) == dict:
+                if value == {} or value == "":
+                    string = string + name + " = '{}', "
+                else:
+                    string = string + name + " = '" + json.dumps(value) + "', "
 
-    #print(payload)
-    print("PAYLOAD: " + json.dumps(payload))
-    print("REQUIRED ITEMS: " + json.dumps(required_items))
+            elif type(value) is list:
 
-    try:
-        for key, value in required_items.items():
-            #print(key)
-            if isinstance(value, type(payload[key])) == True \
-                    and key in payload.keys() and len(required_items) == len(payload):
-                #print(key)
-                pass
+                if is_list_of_jsons(value) is True and value != []:
+                    value = json.dumps(value).replace("[", "{'").replace("]", "'}")
+                    string = string + " " + value + ", "
+
+                else:
+                    value = json.dumps(value).replace("[", "{").replace("]", "}")
+                    string = string + name + " = '" + value + "', "
             else:
-                #print(key)
-                return False
-                break
-        return True
-    except:
-        print(key)
-        return False
+                string = string + name + " = '" + value + "', "
 
+    update_string = (
+            "UPDATE " + table + " SET " + string[:-2]
+            + " WHERE " + key + " = '" + key_value + "'"
+    )
 
-def object_mapper(object, result):
-    mapped_object = {}
-    x = 0
-    for key in object:
-        if key not in ["created_at", "updated_at"]:
-            mapped_object[key] = result[x]
-            x += 1
+    update_string = update_string.replace("'", "\'")
 
-    return mapped_object
+    print("UPDATE STRING: " + update_string)
 
-def is_json(object):
-    try:
-        json_object = json.loads(object)
-        for x, y in json_object.items():
-            pass
-    except:
-        return False
-    return True
\ No newline at end of file
+    return update_string
\ No newline at end of file
